#!/bin/sh

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

#
# Low level developer's support utility functions.
#
# WARNING: No NLS support here.
#

#
# Outputs arguments to "stderr".
#
_report() {
	>&2 echo "$@"
}

_report_error() {
	_report "INTERNAL ERROR:" "$@"
}

#
# Aborts execution printing diagnostic message.
#
_abort_execution() {
	if [ $# -ne 0 ] ; then
		_report_error "ABORT: '$@', execution aborted"
	else
		_report_error "ABORT: execution aborted"
	fi
	exit 1
}
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

_get_arch_subdir() {
	local ARCH
	local ARCH_SUBDIR

	#if [ -n "${FORCEARCH}" ] ; then
	#	ARCH="${FORCEARCH}"
	#elif { which rpm && rpm -q rpm; } >/dev/null 2>&1 ; then
	if { which rpm && rpm -q rpm; } >/dev/null 2>&1 ; then
		#log_message "using 'rpm'"
		ARCH="$(rpm -q rpm --qf "%{ARCH}\n")"
	elif which dpkg >/dev/null 2>&1 ; then
		#log_message "using 'dpkg'"
		ARCH="$(dpkg --print-architecture)"
	else
		#log_message "using 'uname'"
		ARCH="$(uname -m)"
   fi
	#log_variable ARCH

	case "${ARCH}" in
		"i386"|"i486"|"i586"|"i686")
			ARCH_SUBDIR="i386"
			;;

		"x86_64"|"amd64")
			ARCH_SUBDIR="x86_64"
			;;

		"arm")
			ARCH_SUBDIR="arm"
			;;

		"mips"|"mips32"|"mipsel")
			ARCH_SUBDIR="mips32"
			;;

		"mips64"|"mips64r2"|"mips64el")
			ARCH_SUBDIR="mips64"
			;;

		"armv8-a"|"armv8"|"arm64"|"aarch64")
			ARCH_SUBDIR="aarch64"
			;;

		*)
			_abort_execution "Unexpected architecture '${ARCH}'"
			;;
	esac
	#log_variable ARCH_SUBDIR

        echo "${ARCH_SUBDIR}"
}


SCRIPTS_DIR=$(dirname "$0")
if [ "$SCRIPTS_DIR" = "." ] ; then
	CUR_DIR=$(pwd)
else
	CUR_DIR=$SCRIPTS_DIR
fi
echo "$SCRIPTS_DIR"
echo "$CUR_DIR"
ARCH="$(_get_arch_subdir)"
echo "CPU_ARCH:$ARCH"
if [ -z "$(find /usr/lib64 -name sane -type d)" ] ; then
	LIB_SANE="$(find /usr/lib -name libsane.so.1 -type l)"
else
	LIB_SANE="$(find /usr/lib64 -name libsane.so.1 -type l)"
fi
PATH_SANE=$(dirname "$LIB_SANE")
echo "$LIB_SANE"

cp $CUR_DIR/$ARCH/sane/lib/sane/libsane-htsy* $PATH_SANE/sane -R -f
#ln -b -f -s $PATH_SANE/sane/libsane-dll.so.1.0.27 $PATH_SANE/sane/libsane-dll.so
#ln -b -f -s $PATH_SANE/sane/libsane-dll.so.1.0.27 $PATH_SANE/sane/libsane-dll.so.1
ln -b -f -s $PATH_SANE/sane/libsane-htsy.so.1.0.25 $PATH_SANE/sane/libsane-htsy.so
ln -b -f -s $PATH_SANE/sane/libsane-htsy.so.1.0.25 $PATH_SANE/sane/libsane-htsy.so.1

if [ "$ARCH" = "aarch64" ] ; then

if [ -z "$(find $PATH_SANE -name libjpeg.so.8 -type l)" ] ; then
	echo "copy libjpeg.so to $PATH_SANE "
	cp $CUR_DIR/$ARCH/sane/lib/sane/libjpeg* $PATH_SANE -R -f
else
	echo "$PATH_SANE/libjpeg.so.8 exist "
fi

else

if [ -z "$(find $PATH_SANE -name libjpeg.so.62 -type l)" ] ; then
	echo "copy libjpeg.so to $PATH_SANE "
	cp $CUR_DIR/$ARCH/sane/lib/sane/libjpeg* $PATH_SANE -R -f
else
	echo "$PATH_SANE/libjpeg.so.62 exist "
fi

fi

cp $CUR_DIR/$ARCH/sane/etc/sane.d/htsy.conf /etc/sane.d -R -f
if [ -z $(cat /etc/sane.d/dll.conf | grep "htsy") ] ; then
	echo 'htsy' >>/etc/sane.d/dll.conf
fi

cp $CUR_DIR/$ARCH/10-htsy.rules /etc/udev/rules.d -R -f
	
if [ -z "$(find $PATH_SANE -name libdaemon.so.0 -type l)" ] ; then
	echo "copy libdaemon.so.0 to $PATH_SANE "
	cp $CUR_DIR/$ARCH/libdaemon/lib/libdaemon.so* $PATH_SANE -R -f
else
	echo "$PATH_SANE/libdaemon.so.0 exist "
fi

if [ -z "$(find $PATH_SANE -name libavahi-core.so -type l)" ] ; then
	echo "copy libavahi-core.so to $PATH_SANE "
	cp $CUR_DIR/$ARCH/avahi/lib/libavahi-core.so* $PATH_SANE -R -f
else
	echo "$PATH_SANE/libavahi-core.so exist "
fi

if [ -z "$(find /etc/avahi -name avahi-daemon.conf -type f)" ] ; then
	echo "copy avahi-daemon.conf to /etc/avahi "
	mkdir /opt/avahi
	mkdir /opt/avahi/etc
	mkdir /opt/avahi/etc/avahi
	mkdir /opt/avahi/sbin
	mkdir /opt/avahi/var
	mkdir /opt/avahi/var/run
	mkdir /opt/avahi/var/run/avahi-daemon
	mkdir /opt/avahi/etc/avahi/services
	cp $CUR_DIR/$ARCH/avahi/etc/avahi/avahi-daemon.conf /opt/avahi/etc/avahi -R -f
	cp $CUR_DIR/$ARCH/avahi/sbin/avahi-daemon /opt/avahi/sbin -R -f
	cp $CUR_DIR/$ARCH/avahi/etc/avahi/services/sftp-ssh.service /opt/avahi/etc/avahi/services -R -f
	cp $CUR_DIR/$ARCH/avahi/etc/avahi/services/ssh.service /opt/avahi/etc/avahi/services -R -f
	cp $CUR_DIR/$ARCH/avahi/etc/init.d/avahi-daemon.service /usr/lib/systemd/system -R -f
	cp $CUR_DIR/$ARCH/avahi/etc/init.d/avahi-daemon.socket /usr/lib/systemd/system -R -f
	cp $CUR_DIR/$ARCH/avahi/share/avahi /usr/share -R -f
	cp $CUR_DIR/$ARCH/avahi/share/dbus-1 /usr/share -R -f
	useradd -c "Avahi mDNS/DNS-SD Stack" -d /opt/avahi/var/run/avahi-daemon -s /usr/sbin/nologin avahi
	systemctl enable avahi-daemon.service
	systemctl start avahi-daemon.socket
	systemctl start avahi-daemon.service
else
	echo "/etc/avahi/avahi-daemon.conf exist "
fi

if [ -z "$(find /etc/dbus-1/system.d -name avahi-dbus.conf -type f)" ] ; then
	echo "copy avahi-dbus.conf to /etc/dbus-1/system.d "
	cp $CUR_DIR/$ARCH/avahi/etc/dbus-1/system.d/avahi-dbus.conf /etc/dbus-1/system.d -R -f
else
	echo "/etc/dbus-1/system.d/avahi-dbus.conf exist "
fi

#if [ -z "$(find /etc/init.d -name avahi-daemon -type f)" ] ; then
#	echo "copy avahi-daemon to /etc/init.d "
#	cp $CUR_DIR/$ARCH/avahi/etc/init.d/avahi-daemon /etc/init.d -R -f
#else
#	echo "/etc/init.d/avahi-daemon exist "
#fi


