#!/bin/sh

# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

#
# Low level developer's support utility functions.
#
# WARNING: No NLS support here.
#

#
# Outputs arguments to "stderr".
#
_report() {
	>&2 echo "$@"
}

_report_error() {
	_report "INTERNAL ERROR:" "$@"
}

#
# Aborts execution printing diagnostic message.
#
_abort_execution() {
	if [ $# -ne 0 ] ; then
		_report_error "ABORT: '$@', execution aborted"
	else
		_report_error "ABORT: execution aborted"
	fi
	exit 1
}
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -

_get_arch_subdir() {
	local ARCH
	local ARCH_SUBDIR

	#if [ -n "${FORCEARCH}" ] ; then
	#	ARCH="${FORCEARCH}"
	#elif { which rpm && rpm -q rpm; } >/dev/null 2>&1 ; then
	if { which rpm && rpm -q rpm; } >/dev/null 2>&1 ; then
		#log_message "using 'rpm'"
		ARCH="$(rpm -q rpm --qf "%{ARCH}\n")"
	elif which dpkg >/dev/null 2>&1 ; then
		#log_message "using 'dpkg'"
		ARCH="$(dpkg --print-architecture)"
	else
		#log_message "using 'uname'"
		ARCH="$(uname -m)"
   fi
	#log_variable ARCH

	case "${ARCH}" in
		"i386"|"i486"|"i586"|"i686")
			ARCH_SUBDIR="i386"
			;;

		"x86_64"|"amd64")
			ARCH_SUBDIR="x86_64"
			;;

		"arm")
			ARCH_SUBDIR="arm"
			;;

		"mips"|"mips32"|"mipsel")
			ARCH_SUBDIR="mips32"
			;;

		"mips64"|"mips64r2"|"mips64el")
			ARCH_SUBDIR="mips64"
			;;

		"armv8-a"|"armv8"|"arm64"|"aarch64")
			ARCH_SUBDIR="aarch64"
			;;

		*)
			_abort_execution "Unexpected architecture '${ARCH}'"
			;;
	esac
	#log_variable ARCH_SUBDIR

        echo "${ARCH_SUBDIR}"
}


SCRIPTS_DIR=$(dirname "$0")
if [ "$SCRIPTS_DIR" = "." ] ; then
	CUR_DIR=$(pwd)
else
	CUR_DIR=$SCRIPTS_DIR
fi
echo "$SCRIPTS_DIR"
echo "$CUR_DIR"
ARCH="$(_get_arch_subdir)"
echo "CPU_ARCH:$ARCH"
if [ -z "$(find /usr/lib64 -name sane -type d)" ] ; then
	LIB_SANE="$(find /usr/lib -name libsane.so.1 -type l)"
else
	LIB_SANE="$(find /usr/lib64 -name libsane.so.1 -type l)"
fi
PATH_SANE=$(dirname "$LIB_SANE")
echo "$LIB_SANE"

rm $PATH_SANE/sane/libsane-htsy* -R -f

rm /etc/sane.d/htsy.conf -R -f

rm /etc/udev/rules.d/10-htsy.rules -R -f

if [ -z "$(find /etc/avahi -name avahi-daemon.conf -type f)" ] ; then
	echo "rm avahi-daemon.conf from /etc/avahi "
	systemctl disable avahi-daemon.service
	userdel -f avahi
	rm /usr/share/dbus-1/interfaces/org.freedesktop.Avahi.* -R -f
	rm /usr/share/dbus-1/system-services/org.freedesktop.Avahi.* -R -f
	rm /usr/lib/systemd/system/avahi-daemon.* -R -f
	rm /opt/avahi -R -f
	rm /etc/systemd/system/multi-user.target.wants/avahi-daemon.service -R -f
	rm /etc/systemd/system/socket.target.wants/avahi-daemon.socket -R -f
	rm /etc/dbus-1/system.d/avahi-dbus.conf -R -f
else
	echo "/etc/avahi/avahi-daemon.conf exist "
fi

